[galaxy]
# Ensures subsequent unstable reruns don't use the cached information causing another failure
cache_dir={{ remote_tmp_dir }}/galaxy_cache
server_list=offline,galaxy_ng,secondary,pulp_v2

[galaxy_server.offline]
url={{ offline_server }}

[galaxy_server.pulp_v2]
url={{ pulp_server }}primary/api/
username={{ pulp_user }}
password={{ pulp_password }}
api_version=2

[galaxy_server.galaxy_ng]
url={{ galaxy_ng_server }}content/primary/
token={{ galaxy_ng_token.json.token }}

[galaxy_server.secondary]
url={{ galaxy_ng_server }}content/secondary/
username={{ pulp_user }}
password={{ pulp_password }}
